@@ -1,12 +1,12 @@
 (TeX-add-style-hook "NestedCohort"
  (function
   (lambda ()
-    (LaTeX-add-bibliographies
-     "e:/hkatki/Bibliographies/RiskPrediction"
-     "e:/hkatki/Bibliographies/statbib"
-     "e:/hkatki/Bibliographies/genetics")
     (LaTeX-add-environments
      '("changemargin" 2))
+    (LaTeX-add-bibitems
+     "Abnet:05"
+     "Katki:Mark:08"
+     "Mark:Katki:06")
     (LaTeX-add-labels
      "sec:overview"
      "sec:case-study:-zinc"
@@ -18,13 +18,16 @@
      "sec:relat-risks-hazard"
      "sec:stand-surv-attr"
      "fig:PlotStdSurv"
-     "sec:notes")
+     "sec:other-topics"
+     "sec:how-use-auxiliary"
+     "sec:how-fit-multiple"
+     "sec:full-cohort-analysis"
+     "sec:importing-data-into")
     (TeX-add-symbols
      "bex"
      "eex")
     (TeX-run-style-hooks
      "apalike"
-     "S"
      "psfig"
      "fullpage"
      "latex2e"
